diff --git a/view/it/strings.php b/view/it/strings.php
index 2b1a3c830..3640997d9 100644
--- a/view/it/strings.php
+++ b/view/it/strings.php
@@ -324,6 +324,8 @@ $a->strings[' Please use a shorter name.'] = ' Usa un nome più corto.';
$a->strings[' Name too short.'] = ' Nome troppo corto.';
$a->strings[' Not valid email.'] = ' Email non valida.';
$a->strings['Settings updated.'] = 'Impostazioni aggiornate.';
+$a->strings['Plugin Settings'] = 'Impostazioni Plugin';
+$a->strings['Account Settings'= = 'Impostazioni Account';
$a->strings['OpenID: '] = 'OpenID: ';
$a->strings[" \x28Optional\x29 Allow this OpenID to login to this account."] = " \x28Opzionale\x29 Permetti a questo OpenID di accedere a questo account.";
$a->strings['Profile is not published.'] = 'Il profilo non è pubblicato.';
diff --git a/view/theme/default/style.css b/view/theme/default/style.css
index 086f59c30..240ace896 100644
--- a/view/theme/default/style.css
+++ b/view/theme/default/style.css
@@ -1952,3 +1952,8 @@ a.mail-list-link {
margin-top: 50px;
font-size: 70%;
}
+
+
+#plugin-settings-link, #account-settings-link {
+ margin-bottom: 25px;
+}
diff --git a/addon/randplace/randplace.php b/addon/randplace/randplace.php
index e14ae74c7..6203dab8f 100644
--- a/addon/randplace/randplace.php
+++ b/addon/randplace/randplace.php
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
* Then we'll attach into the settings page, on both the
* form and post hooks so that we can create and update
* user preferences.
*
*/
- register_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ register_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
register_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("installed randplace");
@@ -60,7 +60,7 @@ function randplace_uninstall() {
*/
unregister_hook('post_local', 'addon/randplace/randplace.php', 'randplace_post_hook');
- unregister_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ unregister_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
unregister_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
@@ -154,7 +154,7 @@ function randplace_settings(&$a,&$s) {
if(! local_user())
return;
- /* Add our stylesheet so we can match the page layout */
+ /* Add our stylesheet so we can make our settings look nice */
$a->page['htmlhead'] .= '' . "\r\n";
@@ -164,7 +164,7 @@ function randplace_settings(&$a,&$s) {
$checked = (($enabled) ? ' checked="checked" ' : '');
- /* Add some HTML to the form */
+ /* Add some HTML to the existing form */
$s .= '
+
+
$nickname_block
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
- * Then we'll attach into the settings page, on both the
- * form and post hooks so that we can create and update
+ * Then we'll attach into the plugin settings page, and also the
+ * settings post hooks so that we can create and update
* user preferences.
*